@@ -30,7 +30,10 @@ fn main() {
     };
     if !args.all {
         mounts.retain(|m|
-            m.disk.is_some() // by default only fs with disks are shown
+            (
+                m.disk.is_some() // by default only fs with disks are shown
+                || m.info.fs_type == "zfs" // unless it's zfs - see https://github.com/Canop/lfs/issues/32
+            )
             && !m.info.bound // removing bound mounts
             && m.info.fs_type != "squashfs", // quite ad-hoc...
         );
